import { Component } from "react";
import { View, Text } from "@tarojs/components";
import { AtTabs, AtTabsPane } from "taro-ui";
import "./index.less";
import Taro from "@tarojs/taro";
import ProductList from "../../../components/index/ProductList";
import { getBrowseShopProductList,addShopProduct } from "../../../service";
export default class Index extends Component {
  state = {
    current: 0, // 当前选中的标签页索引
    tabList: [
      { title: "全部商品" },
      { title: "选项2" },
      { title: "选项3" },
      { title: "选项4" },
    ], // 标签页列表
    productList: [], // 商品列表
    page: 1, //页数
    loading: false, //加载状态
    totalPages: 1, // 添加总页数
  };
  handleClick(value) {
    this.setState({
      current: value,
    });
  }
  componentDidMount() {
    this.getBrowseShopProductList();
  }
  // 获取商品列表
  getBrowseShopProductList = async (isAdd=false) => {
    const { page } = this.state;
    this.setState({ loading: true });

    const res = await getBrowseShopProductList({
      tag_name: "",
      page,
      page_size: 10,
    });

    this.setState((prevState) => ({
      productList:isAdd ?  res.goods_list: [...prevState.productList, ...res.goods_list],
      totalPages: res.total_pages,
      loading: false,
    }));
  };
  // 添加商品
  onAddProduct = (productId) => {
    addShopProduct({
      goods_ids: [productId],
    }).then(res => {
      if(res.success==true){
        this.getBrowseShopProductList(true);
        Taro.showToast({
          title: '添加成功',
          icon: 'none',
        });
      }
    });
  };
  // 页面上拉触底
  onReachBottom = () => {
    const { page, totalPages, loading } = this.state;
    if (page < totalPages && !loading) {
      this.setState(
        (prevState) => ({ page: prevState.page + 1 }),
        () => this.getBrowseShopProductList()
      );
    }
  };
  render() {
    return (
      <View className="index">
        <AtTabs
          current={this.state.current}
          tabList={this.state.tabList}
          onClick={this.handleClick.bind(this)}
        >
          {this.state.tabList.map((tab, index) => (
            <AtTabsPane current={this.state.current} index={index} key={index}>
              <View className="tab-content">
                <ProductList loading={this.state.loading} productList={this.state.productList} isProductClassify={true} onAddProduct={this.onAddProduct} />
              </View>
            </AtTabsPane>
          ))}
        </AtTabs>
        {/* 底部按钮 */}
        <View onClick={() => Taro.navigateBack()} className="bottom-button">
          返回店铺首页
        </View>
      </View>
    );
  }
}
